```python
from cemir_print.ccprint import ccprint
```

```python
ccprint("Hello, World!")
ccprint([1, 2, 3, 4, 5, 6,{"name": "İzmir", "plaka": 35}])
ccprint(42)
ccprint(False)
```

```python
ccprint({
    "name": "muslu yüksektepe",
    "age": 30,
    "city": "İstanbul",
    "whereareyoufrom": "Türkiye",
    "are_you_ok": True,
    "listem": [1, 3.14, 3, "ceylan", "emir", "muslu", "cem", {"age": 35, "number":{"float": 35.58}}]
})

```

![Örnek Çıktı](https://raw.githubusercontent.com/muslu/cemir_print/main/output.png)

[](https://)
